/***** XBEE APPLICATION PROJECT *****
 * 
 * Auto-generated header with information about the 
 * relation between the XBee module pins and the 
 * project components.
 * 
 ************ XBEE LAYOUT ***********
 * 
 * This layout represents the XBee S2B module selected 
 * for the project with its pin distribution:
 *               _________________
 *              /     ________    \ 
 *             /     |   __   |    \ 
 *            /      | //  \\ |     \ 
 *   XPIN1  -|       | \\__// |      |- XPIN20
 *   XPIN2  -|       |________|      |- XPIN19
 *   XPIN3  -|                       |- XPIN18
 *   XPIN4  -| ===================== |- XPIN17
 *   XPIN5  -| #   # ####  #### #### |- XPIN16
 *   XPIN6  -|  # #  #   # #    #    |- XPIN15
 *   XPIN7  -|   #   ####  ###  ###  |- XPIN14
 *   XPIN8  -|  # #  #   # #    #    |- XPIN13
 *   XPIN9  -| #   # ####  #### #### |- XPIN12
 *   XPIN10 -| ===================== |- XPIN11
 *           |_______________________|
 * 
 ************ PINS LEGEND ***********
 * 
 * The following list displays all the XBee Module pins 
 * with the project component which is using each one:
 * 
 *   XPIN1 = VCC
 *   XPIN2 = uart0 [TX Pin]
 *   XPIN3 = uart0 [RX Pin]
 *   XPIN4 = <<UNUSED>>
 *   XPIN5 = special0 [Reset Pin]
 *   XPIN6 = special0 [RSSI PWM Pin]
 *   XPIN7 = <<UNUSED>>
 *   XPIN8 = special0 [BKGD Pin]
 *   XPIN9 = <<UNUSED>>
 *   XPIN10 = GND
 *   XPIN11 = <<UNUSED>>
 *   XPIN12 = <<UNUSED>>
 *   XPIN13 = <<UNUSED>>
 *   XPIN14 = <<UNUSED>>
 *   XPIN15 = special0 [Association Pin]
 *   XPIN16 = <<UNUSED>>
 *   XPIN17 = <<UNUSED>>
 *   XPIN18 = gpio18 [GPIO Pin]
 *   XPIN19 = gpio19 [GPIO Pin]
 *   XPIN20 = special0 [Commissioning Pin]
 *
 ************************************/

#include <timer.h>
#include <xbee_config.h>
#include <types.h>

#define PWM_PERIOD_MS		10				// in msec
#define	TIMER_PERIOD		100				// in usec
#define PWM_PERIOD_COUNT	( PWM_PERIOD_MS*1000/TIMER_PERIOD ) // nbr of interrupts for period

unsigned int ISR_Count;						// nbr of interrupts in period
unsigned int PWMvalue_gpi018;				// nbr of interrupts for gpio18 pulse width
unsigned int PWMvalue_gpi019;				// nbr of interrupts for gpio19 pulse width

// the bit & port values for the following I/O definitions were determined using the PXBee block diagram 
#define GPIO18_SET		bset	2, PTBD
#define GPIO18_CLR		bclr	2, PTBD
#define GPIO19_SET		bset	3, PTAD
#define GPIO19_CLR		bclr	3, PTAD

#ifdef timer0_irq 
void timer0_irq(void)
{
	ISR_Count++;							// update ISR counter
	if (ISR_Count >= PWM_PERIOD_COUNT)		// if end of period
	{	ISR_Count = 0;						// start pulses
	asm
		{	GPIO18_SET
			GPIO19_SET
		}
	}
	else	// if not end of period
	{
		if ( ISR_Count >= PWMvalue_gpi018 )	// if pulse should be off
		{	asm	{ GPIO18_CLR
				}
		}
		if ( ISR_Count >= PWMvalue_gpi019 )	// if pulse should be off
		{	asm	{ GPIO19_CLR
				}
		}
	}
}
#endif

void main(void)
{
	sys_hw_init();
	sys_xbee_init();
	sys_app_banner();

	ISR_Count = 1;							// initialize so that no pulses are started
	PWMvalue_gpi018 = 10;					// initialize pulse width values	
	PWMvalue_gpi019 = 20;	
	timer_config ( timer0, 1, PERIODIC, TIMER_PERIOD );	// enable periodic interrupt
	
	for (;;) {
		/* Write your code here... */
		sys_watchdog_reset();
		sys_xbee_tick();
	}
}
